@@ -1,7 +1,5 @@
 var NAVTREEINDEX15 =
 {
-"structZydisDecodedInstructionRawEvex.html#a9d167ea54fe7c99a9ab894cd59bb70ac":[1,0,5,7],
-"structZydisDecodedInstructionRawEvex.html#ab03629a7d9a5c2c99ec7b8720ceaca2b":[1,0,5,12],
 "structZydisDecodedInstructionRawEvex.html#ab5e8ad79c7b6e8e6218afbc1fbcc7ad1":[1,0,5,2],
 "structZydisDecodedInstructionRawEvex.html#ab99ca6d4577c9a715763b83f67481132":[1,0,5,14],
 "structZydisDecodedInstructionRawEvex.html#ac9511f0f748f6506769fd287738818da":[1,0,5,11],
@@ -62,29 +60,29 @@ var NAVTREEINDEX15 =
 "structZydisDecodedInstructionRaw__.html#acf5928486654f9fe2ffe11277412baed":[1,0,4,5],
 "structZydisDecodedInstructionRaw__.html#ae5fd55f195a7e401b2bd782bcb00a653":[1,0,4,14],
 "structZydisDecodedInstructionRaw__.html#af820a74a29e29d44c0e0ec11bc72bccf":[1,0,4,15],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html":[1,0,4,0],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#a085405fb2ec715526d15548547841b64":[1,0,4,0,3],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#a48381481ab4e317449d162023f3355b1":[1,0,4,0,0],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,0,1],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#ae1b46f2093f94b55f68a3082b6116225":[1,0,4,0,2],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html":[1,0,4,1],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html#a51dd38788728d5b76de8096e9a15c51f":[1,0,4,1,1],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html#a59a4b593cacfc6b304dea98d3f31f1d3":[1,0,4,1,2],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,1,0],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html":[1,0,4,2],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a51dd38788728d5b76de8096e9a15c51f":[1,0,4,2,4],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a65563abb14a6a0196df0ff540b9c3fa5":[1,0,4,2,1],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a6627cbb5069aea967215a9cb561ae63e":[1,0,4,2,2],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,2,3],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#ac8ef4b34ce4f2f974ef0ad092503e9eb":[1,0,4,2,5],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawPrefixes__.html":[1,0,4,3],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawPrefixes__.html#a02c956465c7d6a2629001b7110e87467":[1,0,4,3,0],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawPrefixes__.html#a44074c0070e1ce67efc1223073f528f3":[1,0,4,3,1],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html":[1,0,4,4],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#a394ad3089c79949845c8f936a03199f4":[1,0,4,4,0],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#a86db95449a20ca13162e15573acee93e":[1,0,4,4,3],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,4,2],
-"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#af41f2dfe85c70e92e5f38be944277d41":[1,0,4,4,1],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html":[1,0,4,1],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#a085405fb2ec715526d15548547841b64":[1,0,4,1,3],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#a48381481ab4e317449d162023f3355b1":[1,0,4,1,0],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,1,1],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionModRm__.html#ae1b46f2093f94b55f68a3082b6116225":[1,0,4,1,2],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html":[1,0,4,3],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html#a51dd38788728d5b76de8096e9a15c51f":[1,0,4,3,1],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html#a59a4b593cacfc6b304dea98d3f31f1d3":[1,0,4,3,2],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawDisp__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,3,0],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html":[1,0,4,4],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a51dd38788728d5b76de8096e9a15c51f":[1,0,4,4,4],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a65563abb14a6a0196df0ff540b9c3fa5":[1,0,4,4,1],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a6627cbb5069aea967215a9cb561ae63e":[1,0,4,4,2],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,4,3],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawImm__.html#ac8ef4b34ce4f2f974ef0ad092503e9eb":[1,0,4,4,5],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawPrefixes__.html":[1,0,4,0],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawPrefixes__.html#a02c956465c7d6a2629001b7110e87467":[1,0,4,0,0],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawPrefixes__.html#a44074c0070e1ce67efc1223073f528f3":[1,0,4,0,1],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html":[1,0,4,2],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#a394ad3089c79949845c8f936a03199f4":[1,0,4,2,0],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#a86db95449a20ca13162e15573acee93e":[1,0,4,2,3],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#a8d5477b227873d2ef2511b78e3221128":[1,0,4,2,2],
+"structZydisDecodedInstructionRaw___1_1ZydisDecodedInstructionRawSib__.html#af41f2dfe85c70e92e5f38be944277d41":[1,0,4,2,1],
 "structZydisDecodedInstruction__.html":[1,0,1],
 "structZydisDecodedInstruction__.html#a1409f3c79728888de80b633050ec5cc5":[1,0,1,9],
 "structZydisDecodedInstruction__.html#a18c387fde82a9129c58a785e471e4544":[1,0,1,14],
@@ -183,15 +181,15 @@ var NAVTREEINDEX15 =
 "structZydisEncodableInstruction__.html":[1,0,20],
 "structZydisEncodableInstruction__.html#a06122156239127e5c45caa3cb991ea90":[1,0,20,13],
 "structZydisEncodableInstruction__.html#a0968fc2622f601ef37f4fb0d84e2f405":[1,0,20,10],
-"structZydisEncodableInstruction__.html#a228ba7443453548e8750cfd435bee35c":[1,0,20,1],
-"structZydisEncodableInstruction__.html#a40309b962b7d02130aec9efc52984fab":[1,0,20,4],
+"structZydisEncodableInstruction__.html#a228ba7443453548e8750cfd435bee35c":[1,0,20,0],
+"structZydisEncodableInstruction__.html#a40309b962b7d02130aec9efc52984fab":[1,0,20,3],
 "structZydisEncodableInstruction__.html#a4063f9b805dc764709078660c5a80a7b":[1,0,20,11],
-"structZydisEncodableInstruction__.html#a4b51427f56289fda4121fbe540b6ea46":[1,0,20,9],
+"structZydisEncodableInstruction__.html#a4b51427f56289fda4121fbe540b6ea46":[1,0,20,7],
 "structZydisEncodableInstruction__.html#a4d6b825b5fc57d2a73638e5911ad8a97":[1,0,20,12],
 "structZydisEncodableInstruction__.html#a6fbf5516bc0e6febafe8c7fddde53fb4":[1,0,20,6],
-"structZydisEncodableInstruction__.html#a7e353373f79b32b443a11d2437588c80":[1,0,20,7],
-"structZydisEncodableInstruction__.html#a89cedff342588902737b09377d537b8b":[1,0,20,3],
-"structZydisEncodableInstruction__.html#a909e0e2855d6649b63e1ab97c660a9a3":[1,0,20,0],
+"structZydisEncodableInstruction__.html#a7e353373f79b32b443a11d2437588c80":[1,0,20,9],
+"structZydisEncodableInstruction__.html#a89cedff342588902737b09377d537b8b":[1,0,20,4],
+"structZydisEncodableInstruction__.html#a909e0e2855d6649b63e1ab97c660a9a3":[1,0,20,1],
 "structZydisEncodableInstruction__.html#ae03dc07552358284df47fd532007b5f7":[1,0,20,2],
 "structZydisEncodableInstruction__.html#aeb49863cff56e995d7a040b495df10aa":[1,0,20,5],
 "structZydisEncodableInstruction__.html#aff828c8349c7283cff0b8d47488c7fc6":[1,0,20,8],
@@ -213,9 +211,9 @@ var NAVTREEINDEX15 =
 "structZydisEncoderOperand___1_1ZydisEncoderOperandPtr__.html":[1,0,22,2],
 "structZydisEncoderOperand___1_1ZydisEncoderOperandPtr__.html#a8578feeea7f157eea4b9a7cae991ea45":[1,0,22,2,0],
 "structZydisEncoderOperand___1_1ZydisEncoderOperandPtr__.html#af2c89ad85e3f5aa084ee9f8c8ae84358":[1,0,22,2,1],
-"structZydisEncoderOperand___1_1ZydisEncoderOperandReg__.html":[1,0,22,3],
-"structZydisEncoderOperand___1_1ZydisEncoderOperandReg__.html#a9b219501dcf5651392c04683e87ab505":[1,0,22,3,0],
-"structZydisEncoderOperand___1_1ZydisEncoderOperandReg__.html#afff15511cc8333e81905217bf669f73f":[1,0,22,3,1],
+"structZydisEncoderOperand___1_1ZydisEncoderOperandReg__.html":[1,0,22,0],
+"structZydisEncoderOperand___1_1ZydisEncoderOperandReg__.html#a9b219501dcf5651392c04683e87ab505":[1,0,22,0,0],
+"structZydisEncoderOperand___1_1ZydisEncoderOperandReg__.html#afff15511cc8333e81905217bf669f73f":[1,0,22,0,1],
 "structZydisEncoderRelInfo__.html":[1,0,23],
 "structZydisEncoderRelInfo__.html#a116c545d35e4061c16e68578bfd31905":[1,0,23,3],
 "structZydisEncoderRelInfo__.html#a30556133e269d9eb8a0aa500f27ad3cc":[1,0,23,1],
@@ -247,7 +245,9 @@ var NAVTREEINDEX15 =
 "structZydisEncoderRequest___1_1ZydisEncoderRequestMvexFeatures__.html#aa81d7f5d359e9f6f54b4a2dd1ad1f679":[1,0,24,1,5],
 "structZydisEncoderRequest___1_1ZydisEncoderRequestMvexFeatures__.html#afeb91b0aa83078f95530cd8fbae4a6c8":[1,0,24,1,0],
 "structZydisFormatterBuffer__.html":[1,0,26],
-"structZydisFormatterBuffer__.html#aa2e6fb7a114827fb81b2415c44645ece":[1,0,26,2],
+"structZydisFormatterBuffer__.html#aa2e6fb7a114827fb81b2415c44645ece":[1,0,26,1],
 "structZydisFormatterBuffer__.html#aa5c579294bebe0bd4deaa46d8fb4c0c4":[1,0,26,0],
-"structZydisFormatterBuffer__.html#ac35aa2997c8157e9fcf05b663a3511b6":[1,0,26,1]
+"structZydisFormatterContext__.html":[1,0,27],
+"structZydisFormatterContext__.html#a0c280d6e14b6091c5217ed5e978f0ea3":[1,0,27,0],
+"structZydisFormatterContext__.html#a0f53d287ac7c064d1a49d4bd93ca1cb9":[1,0,27,4]
 };
